/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */
AUI.add('liferay-calendar-remote-services', function (A) {
  var Lang = A.Lang;
  var isString = Lang.isString;
  var toInt = Lang.toInt;
  var CalendarUtil = Liferay.CalendarUtil;
  var MessageUtil = Liferay.CalendarMessageUtil;
  var STR_BLANK = '';
  var CalendarRemoteServices = A.Base.create('calendar-remote-services', A.Base, [Liferay.PortletBase], {
    _invokeActionURL: function _invokeActionURL(config) {
      var instance = this;
      var actionParameters = {
        'javax.portlet.action': config.actionName
      };
      A.mix(actionParameters, config.queryParameters);
      var url = Liferay.Util.PortletURL.createActionURL(instance.get('baseActionURL'), actionParameters);
      var payload;

      if (config.payload) {
        payload = Liferay.Util.ns(instance.get('namespace'), config.payload);
      }

      var data = new URLSearchParams();
      Object.keys(payload).forEach(function (key) {
        data.append(key, payload[key]);
      });
      Liferay.Util.fetch(url.toString(), {
        body: data,
        method: 'POST'
      }).then(function (response) {
        return response.json();
      }).then(function (data) {
        config.callback(data);
      });
    },
    _invokeResourceURL: function _invokeResourceURL(config) {
      var instance = this;
      var resourceParameters = {
        doAsUserId: Liferay.ThemeDisplay.getDoAsUserIdEncoded(),
        p_p_resource_id: config.resourceId
      };
      A.mix(resourceParameters, config.queryParameters);
      var url = Liferay.Util.PortletURL.createResourceURL(instance.get('baseResourceURL'), resourceParameters);
      var payload;

      if (config.payload) {
        payload = Liferay.Util.ns(instance.get('namespace'), config.payload);
      }

      var data = new URLSearchParams();

      if (payload) {
        Object.keys(payload).forEach(function (key) {
          data.append(key, payload[key]);
        });
      }

      Liferay.Util.fetch(url.toString(), {
        body: data,
        method: 'POST'
      }).then(function (response) {
        return response.text();
      }).then(function (data) {
        if (data.length) {
          config.callback(JSON.parse(data));
        }
      });
    },
    _invokeService: function _invokeService(payload, callback) {
      var _this = this;

      var instance = this;
      callback = callback || {};
      var data = new URLSearchParams();
      data.append('cmd', JSON.stringify(payload));
      data.append('payload', Liferay.authToken);
      Liferay.Util.fetch(instance.get('invokerURL'), {
        body: data,
        method: 'POST'
      }).then(function (response) {
        return response.json();
      }).then(function (data) {
        if (typeof callback.success === 'function') {
          callback.success.apply(_this, [data]);
        }
      }).catch(function (err) {
        if (typeof callback.failure === 'function') {
          callback.failure(err);
        }
      });
    },
    deleteCalendar: function deleteCalendar(calendarId, callback) {
      var instance = this;

      instance._invokeService({
        '/calendar.calendar/delete-calendar': {
          calendarId: calendarId
        }
      }, {
        success: function success() {
          callback(this.get('responseData'));
        }
      });
    },
    deleteEvent: function deleteEvent(schedulerEvent, _success) {
      var instance = this;

      instance._invokeService({
        '/calendar.calendarbooking/move-calendar-booking-to-trash': {
          calendarBookingId: schedulerEvent.get('calendarBookingId')
        }
      }, {
        success: function success(data) {
          if (_success) {
            _success.call(instance, data);

            MessageUtil.showSuccessMessage(instance.get('rootNode')._node);
          }
        }
      });
    },
    deleteEventInstance: function deleteEventInstance(schedulerEvent, allFollowing, _success2) {
      var instance = this;

      instance._invokeService({
        '/calendar.calendarbooking/delete-calendar-booking-instance': {
          allFollowing: allFollowing,
          calendarBookingId: schedulerEvent.get('calendarBookingId'),
          deleteRecurringCalendarBookings: true,
          instanceIndex: schedulerEvent.get('instanceIndex')
        }
      }, {
        success: function success(data) {
          if (_success2) {
            _success2.call(instance, data);

            MessageUtil.showSuccessMessage(instance.get('rootNode')._node);
          }
        }
      });
    },
    getCalendar: function getCalendar(calendarId, callback) {
      var instance = this;

      instance._invokeResourceURL({
        callback: callback,
        queryParameters: {
          calendarId: calendarId
        },
        resourceId: 'calendar'
      });
    },
    getCalendarBookingInvitees: function getCalendarBookingInvitees(calendarBookingId, callback) {
      var instance = this;

      instance._invokeResourceURL({
        callback: callback,
        queryParameters: {
          parentCalendarBookingId: calendarBookingId
        },
        resourceId: 'calendarBookingInvitees'
      });
    },
    getCalendarRenderingRules: function getCalendarRenderingRules(calendarIds, startDate, endDate, ruleName, callback) {
      var instance = this;

      instance._invokeResourceURL({
        callback: callback,
        payload: {
          calendarIds: calendarIds.join(),
          endTime: endDate.getTime(),
          ruleName: ruleName,
          startTime: startDate.getTime()
        },
        resourceId: 'calendarRenderingRules'
      });
    },
    getCurrentTime: function getCurrentTime(_callback) {
      var instance = this;
      var lastCurrentTime = instance.lastCurrentTime;

      if (lastCurrentTime) {
        var lastBrowserTime = instance.lastBrowserTime;
        var browserTime = new Date();
        var timeDiff = Math.abs(browserTime.getTime() - lastBrowserTime.getTime());
        var currentTime = lastCurrentTime.getTime() + timeDiff;
        lastCurrentTime.setTime(currentTime);
        instance.lastCurrentTime = lastCurrentTime;
        instance.lastBrowserTime = browserTime;

        _callback(instance.lastCurrentTime);

        return;
      }

      instance._invokeResourceURL({
        callback: function callback(dateObj) {
          instance.lastCurrentTime = CalendarUtil.getDateFromObject(dateObj);
          instance.lastBrowserTime = new Date();

          _callback(instance.lastCurrentTime);
        },
        resourceId: 'currentTime'
      });
    },
    getEvent: function getEvent(calendarBookingId, success, failure) {
      var instance = this;

      instance._invokeService({
        '/calendar.calendarbooking/get-calendar-booking': {
          calendarBookingId: calendarBookingId
        }
      }, {
        failure: failure,
        success: success
      });
    },
    getEvents: function getEvents(calendarIds, eventsPerPage, startDate, endDate, status, callback) {
      var instance = this;

      instance._invokeResourceURL({
        callback: callback,
        payload: {
          calendarIds: calendarIds.join(','),
          endTimeDay: endDate.getDate(),
          endTimeHour: endDate.getHours(),
          endTimeMinute: endDate.getMinutes(),
          endTimeMonth: endDate.getMonth(),
          endTimeYear: endDate.getFullYear(),
          eventsPerPage: eventsPerPage,
          startTimeDay: startDate.getDate(),
          startTimeHour: startDate.getHours(),
          startTimeMinute: startDate.getMinutes(),
          startTimeMonth: startDate.getMonth(),
          startTimeYear: startDate.getFullYear(),
          statuses: status.join(',')
        },
        resourceId: 'calendarBookings'
      });
    },
    getResourceCalendars: function getResourceCalendars(calendarResourceId, callback) {
      var instance = this;

      instance._invokeResourceURL({
        callback: callback,
        queryParameters: {
          calendarResourceId: calendarResourceId
        },
        resourceId: 'resourceCalendars'
      });
    },
    hasExclusiveCalendarBooking: function hasExclusiveCalendarBooking(calendarId, startDate, endDate, _callback2) {
      var instance = this;

      instance._invokeResourceURL({
        callback: function callback(result) {
          _callback2(result.hasExclusiveCalendarBooking);
        },
        queryParameters: {
          calendarId: calendarId,
          endTimeDay: endDate.getDate(),
          endTimeHour: endDate.getHours(),
          endTimeMinute: endDate.getMinutes(),
          endTimeMonth: endDate.getMonth(),
          endTimeYear: endDate.getFullYear(),
          startTimeDay: startDate.getDate(),
          startTimeHour: startDate.getHours(),
          startTimeMinute: startDate.getMinutes(),
          startTimeMonth: startDate.getMonth(),
          startTimeYear: startDate.getFullYear()
        },
        resourceId: 'hasExclusiveCalendarBooking'
      });
    },
    invokeTransition: function invokeTransition(schedulerEvent, instanceIndex, status, updateInstance, allFollowing) {
      var instance = this;
      var scheduler = schedulerEvent.get('scheduler');

      instance._invokeService({
        '/calendar.calendarbooking/invoke-transition': {
          allFollowing: allFollowing,
          calendarBookingId: schedulerEvent.get('calendarBookingId'),
          instanceIndex: instanceIndex,
          status: status,
          updateInstance: updateInstance,
          userId: instance.get('userId')
        }
      }, {
        start: function start() {
          schedulerEvent.set('loading', true, {
            silent: true
          });
        },
        success: function success(data) {
          schedulerEvent.set('loading', false, {
            silent: true
          });

          if (data && !data.exception && scheduler) {
            var eventRecorder = scheduler.get('eventRecorder');
            eventRecorder.hidePopover();
            scheduler.load();
          }
        }
      });
    },
    updateCalendarColor: function updateCalendarColor(calendarId, color) {
      var instance = this;

      instance._invokeService({
        '/calendar.calendar/update-color': {
          calendarId: calendarId,
          color: parseInt(color.substr(1), 16)
        }
      });
    },
    updateEvent: function updateEvent(schedulerEvent, updateInstance, allFollowing, success) {
      var instance = this;
      var endDate = schedulerEvent.get('endDate');
      var startDate = schedulerEvent.get('startDate');

      instance._invokeActionURL({
        actionName: 'updateSchedulerCalendarBooking',
        callback: function callback(data) {
          schedulerEvent.set('loading', false, {
            silent: true
          });

          if (data) {
            if (data.exception) {
              CalendarUtil.destroyEvent(schedulerEvent);
              MessageUtil.showErrorMessage(instance.get('rootNode')._node, data.exception);
            } else {
              CalendarUtil.setEventAttrs(schedulerEvent, data);

              if (success) {
                success.call(instance, data);
                MessageUtil.showSuccessMessage(instance.get('rootNode')._node);
              }
            }
          }
        },
        payload: {
          allDay: schedulerEvent.get('allDay'),
          allFollowing: allFollowing,
          calendarBookingId: schedulerEvent.get('calendarBookingId'),
          calendarId: schedulerEvent.get('calendarId'),
          endTimeDay: endDate.getDate(),
          endTimeHour: endDate.getHours(),
          endTimeMinute: endDate.getMinutes(),
          endTimeMonth: endDate.getMonth(),
          endTimeYear: endDate.getFullYear(),
          instanceIndex: schedulerEvent.get('instanceIndex'),
          recurrence: schedulerEvent.get('recurrence'),
          startTimeDay: startDate.getDate(),
          startTimeHour: startDate.getHours(),
          startTimeMinute: startDate.getMinutes(),
          startTimeMonth: startDate.getMonth(),
          startTimeYear: startDate.getFullYear(),
          title: Liferay.Util.unescapeHTML(schedulerEvent.get('content')),
          updateInstance: updateInstance
        }
      });
    }
  }, {
    ATTRS: {
      baseActionURL: {
        validator: isString,
        value: STR_BLANK
      },
      baseResourceURL: {
        validator: isString,
        value: STR_BLANK
      },
      invokerURL: {
        validator: isString,
        value: STR_BLANK
      },
      userId: {
        setter: toInt
      }
    }
  });
  Liferay.CalendarRemoteServices = CalendarRemoteServices;
}, '', {
  requires: ['aui-base', 'aui-component', 'liferay-calendar-message-util', 'liferay-calendar-util', 'liferay-portlet-base']
});
//# sourceMappingURL=remote_services.js.map